@@ -1,6 +1,7 @@
 /*******************************************************************
 * reportassistantpages_bugzilla.cpp
 * Copyright 2009, 2010, 2011    Dario Andres Rodriguez <andresbajotierra@gmail.com>
+* Copyright 2019 Harald Sitter <sitter@kde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
@@ -19,6 +20,7 @@
 
 #include "reportassistantpages_bugzilla.h"
 
+#include <QAction>
 #include <QTimer>
 #include <QLabel>
 #include <QCheckBox>
@@ -29,12 +31,8 @@
 #include <QTextBrowser>
 #include <QDesktopServices>
 
-#include <QDBusInterface>
-#include <QDBusReply>
-
 #include "drkonqi_debug.h"
 #include <KMessageBox>
-#include <KToolInvocation>
 #include <KLocalizedString>
 #include <kwallet.h>
 #include <KCapacityBar>
@@ -66,10 +64,9 @@ static const char konquerorKWalletEntryPassword[] = "Bugzilla_password";
 
 BugzillaLoginPage::BugzillaLoginPage(ReportAssistantDialog * parent) :
         ReportAssistantPage(parent),
-        m_wallet(nullptr), m_walletWasOpenedBefore(false),
-        m_bugzillaVersionFound(false)
+        m_wallet(nullptr),
+        m_walletWasOpenedBefore(false)
 {
-    connect(bugzillaManager(), &BugzillaManager::bugzillaVersionFound, this, &BugzillaLoginPage::bugzillaVersionFound);
     connect(bugzillaManager(), &BugzillaManager::loginFinished, this, &BugzillaLoginPage::loginFinished);
     connect(bugzillaManager(), &BugzillaManager::loginError, this, &BugzillaLoginPage::loginError);
 
@@ -82,7 +79,7 @@ BugzillaLoginPage::BugzillaLoginPage(ReportAssistantDialog * parent) :
                                               QIcon::fromTheme(QStringLiteral("network-connect")),
                                               i18nc("@info:tooltip", "Use this button to login "
                                               "to the KDE bug tracking system using the provided "
-                                              "username and password.")));
+                                              "e-mail address and password.")));
     ui.m_loginButton->setEnabled(false);
 
     connect(ui.m_loginButton, &QPushButton::clicked, this, &BugzillaLoginPage::loginClicked);
@@ -116,28 +113,16 @@ bool BugzillaLoginPage::isComplete()
     return bugzillaManager()->getLogged();
 }
 
-void BugzillaLoginPage::bugzillaVersionFound()
-{
-    // Login depends on first knowing the Bugzilla software version number.
-    m_bugzillaVersionFound = true;
-    updateLoginButtonStatus();
-}
-
 void BugzillaLoginPage::updateLoginButtonStatus()
 {
-    ui.m_loginButton->setEnabled( !ui.m_userEdit->text().isEmpty() &&
-                                  !ui.m_passwordEdit->password().isEmpty() &&
-                                  m_bugzillaVersionFound );
+    ui.m_loginButton->setEnabled(canLogin());
 }
 
-void BugzillaLoginPage::loginError(const QString & err, const QString & extendedMessage)
+void BugzillaLoginPage::loginError(const QString &error)
 {
     loginFinished(false);
     ui.m_statusWidget->setIdle(xi18nc("@info:status","Error when trying to login: "
-                                                 "<message>%1.</message>", err));
-    if (!extendedMessage.isEmpty()) {
-        new UnhandledErrorDialog(this, err, extendedMessage);
-    }
+                                                 "<message>%1</message>", error));
 }
 
 void BugzillaLoginPage::aboutToShow()
@@ -242,70 +227,6 @@ void BugzillaLoginPage::walletLogin()
     }
 }
 
-bool BugzillaLoginPage::canSetCookies()
-{
-    if (bugzillaManager()->securityMethod() != BugzillaManager::UseCookies) {
-        qCDebug(DRKONQI_LOG) << "Bugzilla software no longer issues cookies.";
-        return false;
-    }
-    QDBusInterface kded(QStringLiteral("org.kde.kded5"),
-                        QStringLiteral("/kded"),
-                        QStringLiteral("org.kde.kded5"));
-    QDBusReply<bool> kcookiejarLoaded = kded.call(QStringLiteral("loadModule"),
-                                                  QStringLiteral("kcookiejar"));
-    if (!kcookiejarLoaded.isValid()) {
-        KMessageBox::error(this, i18n("Failed to communicate with kded. Make sure it is running."));
-        return false;
-    } else if (!kcookiejarLoaded.value()) {
-        KMessageBox::error(this, i18n("Failed to load KCookieServer. Check your KDE installation."));
-        return false;
-    }
-
-
-    QDBusInterface kcookiejar(QStringLiteral("org.kde.kded5"),
-                              QStringLiteral("/modules/kcookiejar"),
-                              QStringLiteral("org.kde.KCookieServer"));
-    QDBusReply<QString> advice = kcookiejar.call(QStringLiteral("getDomainAdvice"),
-                                                 KDE_BUGZILLA_URL);
-
-    if (!advice.isValid()) {
-        KMessageBox::error(this, i18n("Failed to communicate with KCookieServer."));
-        return false;
-    }
-
-    qCDebug(DRKONQI_LOG) << "Got reply from KCookieServer:" << advice.value();
-
-    if (advice.value() == QLatin1String("Reject")) {
-        QString msg = i18nc("@info 1 is the bugzilla website url",
-                            "Cookies are not allowed in your KDE network settings. In order to "
-                            "proceed, you need to allow %1 to set cookies.", KDE_BUGZILLA_URL);
-
-        KGuiItem yesItem = KStandardGuiItem::yes();
-        yesItem.setText(i18nc("@action:button 1 is the bugzilla website url",
-                              "Allow %1 to set cookies", KDE_BUGZILLA_URL));
-
-        KGuiItem noItem = KStandardGuiItem::no();
-        noItem.setText(i18nc("@action:button do not allow the bugzilla website "
-                             "to set cookies", "No, do not allow"));
-
-        if (KMessageBox::warningYesNo(this, msg, QString(), yesItem, noItem) == KMessageBox::Yes) {
-            QDBusReply<bool> success = kcookiejar.call(QStringLiteral("setDomainAdvice"),
-                                                       KDE_BUGZILLA_URL,
-                                                       QStringLiteral("Accept"));
-            if (!success.isValid() || !success.value()) {
-                qCWarning(DRKONQI_LOG) << "Failed to set domain advice in KCookieServer";
-                return false;
-            } else {
-                return true;
-            }
-        } else {
-            return false;
-        }
-    }
-
-    return true;
-}
-
 void BugzillaLoginPage::loginClicked()
 {
     if (!canLogin()) {
@@ -313,11 +234,6 @@ void BugzillaLoginPage::loginClicked()
         return;
     }
 
-    if ((bugzillaManager()->securityMethod() == BugzillaManager::UseCookies)
-            && (!canSetCookies())) {
-        return;
-    }
-
     updateWidget(false);
 
     if (ui.m_savePasswordCheckBox->checkState()==Qt::Checked) { //Wants to save data
@@ -351,14 +267,15 @@ void BugzillaLoginPage::loginClicked()
 
 bool BugzillaLoginPage::canLogin() const
 {
-    return (!(ui.m_userEdit->text().isEmpty() || ui.m_passwordEdit->password().isEmpty()));
+    return (!(ui.m_userEdit->text().isEmpty() ||
+              ui.m_passwordEdit->password().isEmpty()));
 }
 
 void BugzillaLoginPage::login()
 {
     Q_ASSERT(canLogin());
 
-    ui.m_statusWidget->setBusy(i18nc("@info:status '1' is a url, '2' the username",
+    ui.m_statusWidget->setBusy(i18nc("@info:status '1' is a url, '2' the e-mail address",
                                      "Performing login at %1 as %2...",
                                      QLatin1String(KDE_BUGZILLA_SHORT_URL),
                                      ui.m_userEdit->text()));
@@ -392,8 +309,8 @@ void BugzillaLoginPage::loginFinished(bool logged)
 
         emit loggedTurnToNextPage();
     } else {
-        ui.m_statusWidget->setIdle(i18nc("@info:status","<b>Error: Invalid username or "
-                                                                                  "password</b>"));
+        ui.m_statusWidget->setIdle(i18nc("@info:status",
+                                         "<b>Error: Invalid e-mail address or password</b>"));
         updateWidget(true);
         ui.m_userEdit->setFocus(Qt::OtherFocusReason);
     }
@@ -415,11 +332,12 @@ BugzillaLoginPage::~BugzillaLoginPage()
 //BEGIN BugzillaInformationPage
 
 BugzillaInformationPage::BugzillaInformationPage(ReportAssistantDialog * parent)
-        : ReportAssistantPage(parent),
-        m_textsOK(false), m_distributionComboSetup(false), m_distroComboVisible(false),
-        m_requiredCharacters(1)
+        : ReportAssistantPage(parent)
+        , m_textsOK(false)
+        , m_requiredCharacters(1)
 {
     ui.setupUi(this);
+
     m_textCompleteBar = new KCapacityBar(KCapacityBar::DrawTextInline, this);
     ui.horizontalLayout_2->addWidget(m_textCompleteBar);
 
@@ -429,75 +347,25 @@ BugzillaInformationPage::BugzillaInformationPage(ReportAssistantDialog * parent)
     connect(ui.m_titleLabel, &QLabel::linkActivated, this, &BugzillaInformationPage::showTitleExamples);
     connect(ui.m_detailsLabel, &QLabel::linkActivated, this, &BugzillaInformationPage::showDescriptionHelpExamples);
 
-    ui.m_compiledSourcesCheckBox->setChecked(
-                                    DrKonqi::systemInformation()->compiledSources());
+    ui.m_compiledSourcesCheckBox->setChecked(DrKonqi::systemInformation()->compiledSources());
 
+    ui.m_messageWidget->setVisible(false);
+    auto retryAction = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")),
+                                   i18nc("@action/button retry button in error widget",
+                                         "Retry"),
+                                   ui.m_messageWidget);
+    connect(retryAction, &QAction::triggered,
+            this, [this, retryAction]{
+        ui.m_messageWidget->animatedHide();
+        loadDistroCombo();
+    });
+    ui.m_messageWidget->addAction(retryAction);
+
+    loadDistroCombo();
 }
 
 void BugzillaInformationPage::aboutToShow()
 {
-    if (!m_distributionComboSetup) {
-        //Autodetecting distro failed ?
-        if (DrKonqi::systemInformation()->bugzillaPlatform() == QLatin1String("unspecified")) {
-            m_distroComboVisible = true;
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Unspecified"),QStringLiteral("unspecified"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Archlinux"), QStringLiteral("Archlinux Packages"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Chakra"), QStringLiteral("Chakra"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Debian stable"), QStringLiteral("Debian stable"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Debian testing"), QStringLiteral("Debian testing"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Debian unstable"), QStringLiteral("Debian unstable"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Exherbo"), QStringLiteral("Exherbo Packages"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Fedora"), QStringLiteral("Fedora RPMs"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Gentoo"), QStringLiteral("Gentoo Packages"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Mageia"), QStringLiteral("Mageia RPMs"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Mandriva"), QStringLiteral("Mandriva RPMs"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Neon"), QStringLiteral("Neon Packages"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "OpenSUSE"), QStringLiteral("openSUSE RPMs"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Pardus"), QStringLiteral("Pardus Packages"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "RedHat"), QStringLiteral("RedHat RPMs"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Slackware"), QStringLiteral("Slackware Packages"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Ubuntu (and derivatives)"),
-                                                   QStringLiteral("Ubuntu Packages"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "FreeBSD (Ports)"), QStringLiteral("FreeBSD Ports"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "NetBSD (pkgsrc)"), QStringLiteral("NetBSD pkgsrc"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "OpenBSD"), QStringLiteral("OpenBSD Packages"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Mac OS X"), QStringLiteral("MacPorts Packages"));
-            ui.m_distroChooserCombo->addItem(i18nc("@label:listbox KDE distribution method",
-                                                   "Solaris"), QStringLiteral("Solaris Packages"));
-
-            //Restore previously selected bugzilla platform (distribution)
-            KConfigGroup config(KSharedConfig::openConfig(), "BugzillaInformationPage");
-            QString entry = config.readEntry("BugzillaPlatform","unspecified");
-            int index = ui.m_distroChooserCombo->findData(entry);
-            if ( index == -1 ) index = 0;
-            ui.m_distroChooserCombo->setCurrentIndex(index);
-        } else {
-            ui.m_distroChooserCombo->setVisible(false);
-        }
-        m_distributionComboSetup = true;
-    }
-
     //Calculate the minimum number of characters required for a description
     //If creating a new report: minimum 40, maximum 80
     //If attaching to an existent report: minimum 30, maximum 50
@@ -567,6 +435,80 @@ void BugzillaInformationPage::checkTexts()
     }
 }
 
+void BugzillaInformationPage::loadDistroCombo()
+{
+    // Alway have at least unspecified otherwise bugzilla would get to decide
+    // the platform and that would likely be index=0 which is compiledfromsource
+    ui.m_distroChooserCombo->addItem(QStringLiteral("unspecified"));
+
+    Bugzilla::BugFieldClient client;
+    auto job = client.getField(QStringLiteral("rep_platform"));
+    connect(job, &KJob::finished, this, [this, &client](KJob *job) {
+        try {
+            Bugzilla::BugField::Ptr field = client.getField(job);
+            if (!field) {
+                // This is a bit flimsy but only acts as save guard.
+                // Ideally this code path is never hit.
+                throw Bugzilla::RuntimeException(i18nc("@info/status error",
+                                                       "Failed to get platform list"));
+            }
+            setDistros(field);
+        } catch (Bugzilla::Exception &e) {
+            qCWarning(DRKONQI_LOG) << e.whatString();
+            setDistroComboError(e.whatString());
+        }
+    });
+}
+
+void BugzillaInformationPage::setDistros(const Bugzilla::BugField::Ptr &field)
+{
+    ui.m_distroChooserCombo->clear();
+    for (const auto &distro : field->values()) {
+        ui.m_distroChooserCombo->addItem(distro->name());
+    }
+
+    int index = 0;
+    bool autoDetected = false;
+
+    const QString detectedPlatform = DrKonqi::systemInformation()->bugzillaPlatform();
+    if (detectedPlatform != QLatin1String("unspecified")) {
+        index = ui.m_distroChooserCombo->findText(detectedPlatform);
+        if (index >= 0) {
+            autoDetected = true;
+        }
+    } else {
+        // Restore previously selected bugzilla platform (distribution)
+        KConfigGroup config(KSharedConfig::openConfig(), "BugzillaInformationPage");
+        const QString entry = config.readEntry("BugzillaPlatform", "unspecified");
+        index = ui.m_distroChooserCombo->findText(entry);
+    }
+
+    if (index < 0) { // failed to restore value
+        index = ui.m_distroChooserCombo->findText(QStringLiteral("unspecified"));
+    }
+    if (index < 0) { // also failed to find unspecified... shouldn't happen
+        index = 0;
+    }
+
+    ui.m_distroChooserCombo->setCurrentIndex(index);
+    ui.m_distroChooserCombo->setVisible(autoDetected);
+    ui.m_distroChooserCombo->setDisabled(false);
+}
+
+void BugzillaInformationPage::setDistroComboError(const QString &error)
+{
+    // NB: not being able to resolve the platform isn't a blocking issue.
+    // You can still file a report, it'll simply default to unspecified.
+
+    ui.m_messageWidget->setText(i18nc("@info error when talking to the bugzilla API",
+                                      "An error occurred when talking to bugs.kde.org: %1",
+                                      error));
+    ui.m_messageWidget->animatedShow();
+
+    ui.m_distroChooserCombo->setVisible(true);
+    ui.m_distroChooserCombo->setDisabled(true);
+}
+
 bool BugzillaInformationPage::showNextPage()
 {
     checkTexts();
@@ -628,7 +570,7 @@ void BugzillaInformationPage::aboutToHide()
     reportInterface()->setTitle(ui.m_titleEdit->text());
     reportInterface()->setDetailText(ui.m_detailsEdit->toPlainText());
 
-    if (m_distroComboVisible) {
+    if (ui.m_distroChooserCombo->isVisible()) {
         //Save bugzilla platform (distribution)
         QString bugzillaPlatform = ui.m_distroChooserCombo->itemData(
                                         ui.m_distroChooserCombo->currentIndex()).toString();
@@ -638,7 +580,6 @@ void BugzillaInformationPage::aboutToHide()
     }
     bool compiledFromSources = ui.m_compiledSourcesCheckBox->checkState() == Qt::Checked;
     DrKonqi::systemInformation()->setCompiledSources(compiledFromSources);
-
 }
 
 void BugzillaInformationPage::showTitleExamples()
@@ -657,19 +598,19 @@ void BugzillaInformationPage::showDescriptionHelpExamples()
     QString descriptionHelp = i18nc("@info:tooltip help and examples of good bug descriptions",
                                   "Describe in as much detail as possible the crash circumstances:");
     if (reportInterface()->userCanProvideActionsAppDesktop()) {
-        descriptionHelp += QStringLiteral("<br />") +
+        descriptionHelp += QLatin1String("<br />") +
                            i18nc("@info:tooltip help and examples of good bug descriptions",
                                  "- Detail which actions were you taking inside and outside the "
                                  "application an instant before the crash.");
     }
     if (reportInterface()->userCanProvideUnusualBehavior()) {
-        descriptionHelp += QStringLiteral("<br />") +
+        descriptionHelp += QLatin1String("<br />") +
                            i18nc("@info:tooltip help and examples of good bug descriptions",
                                  "- Note if you noticed any unusual behavior in the application "
                                  "or in the whole environment.");
     }
     if (reportInterface()->userCanProvideApplicationConfigDetails()) {
-        descriptionHelp += QStringLiteral("<br />") +
+        descriptionHelp += QLatin1String("<br />") +
                            i18nc("@info:tooltip help and examples of good bug descriptions",
                                  "- Note any non-default configuration in the application.");
         if (reportInterface()->appDetailsExamples()->hasExamples()) {
@@ -695,7 +636,14 @@ BugzillaPreviewPage::BugzillaPreviewPage(ReportAssistantDialog * parent)
 
 void BugzillaPreviewPage::aboutToShow()
 {
-    ui.m_previewEdit->setText(reportInterface()->generateReportFullText(true));
+    ui.m_previewEdit->setText(reportInterface()->generateReportFullText(ReportInterface::DrKonqiStamp::Include,
+                                                                        ReportInterface::Backtrace::Complete));
+    assistant()->setAboutToSend(true);
+}
+
+void BugzillaPreviewPage::aboutToHide()
+{
+    assistant()->setAboutToSend(false);
 }
 
 //END BugzillaPreviewPage
@@ -741,11 +689,32 @@ void BugzillaSendPage::retryClicked()
 void BugzillaSendPage::aboutToShow()
 {
     ui.m_statusWidget->setBusy(i18nc("@info:status","Sending crash report... (please wait)"));
-    reportInterface()->sendBugReport();
+
+    // Trigger relogin. If the user took a long time to prepare the login our
+    // token might have gone invalid in the meantime. As a cheap way to prevent
+    // this we'll simply refresh the token regardless. It's plenty cheap and
+    // should reliably ensure that the token is current.
+    // Disconnect everything first though, this function may get called a bunch
+    // of times, so we don't want duplicated submissions.
+    disconnect(bugzillaManager(), &BugzillaManager::loginFinished,
+               reportInterface(), &ReportInterface::sendBugReport);
+    disconnect(bugzillaManager(), &BugzillaManager::loginError,
+               this, nullptr);
+    connect(bugzillaManager(), &BugzillaManager::loginFinished,
+            reportInterface(), &ReportInterface::sendBugReport);
+    connect(bugzillaManager(), &BugzillaManager::loginError,
+            this, &BugzillaSendPage::sendError);
+    bugzillaManager()->refreshToken();
 }
 
 void BugzillaSendPage::sent(int bug_id)
 {
+    // Disconnect login->submit chain again.
+    disconnect(bugzillaManager(), &BugzillaManager::loginFinished,
+               reportInterface(), &ReportInterface::sendBugReport);
+    disconnect(bugzillaManager(), &BugzillaManager::loginError,
+               this, nullptr);
+
     ui.m_statusWidget->setVisible(false);
     ui.m_retryButton->setEnabled(false);
     ui.m_retryButton->setVisible(false);
@@ -765,17 +734,13 @@ void BugzillaSendPage::sent(int bug_id)
     emit finished(false);
 }
 
-void BugzillaSendPage::sendError(const QString & errorString, const QString & extendedMessage)
+void BugzillaSendPage::sendError(const QString &errorString)
 {
     ui.m_statusWidget->setIdle(xi18nc("@info:status","Error sending the crash report:  "
                                   "<message>%1.</message>", errorString));
 
     ui.m_retryButton->setEnabled(true);
     ui.m_retryButton->setVisible(true);
-
-    if (!extendedMessage.isEmpty()) {
-        new UnhandledErrorDialog(this,errorString, extendedMessage);
-    }
 }
 
 void BugzillaSendPage::finishClicked()
@@ -792,7 +757,8 @@ void BugzillaSendPage::openReportContents()
 {
     if (!m_contentsDialog)
     {
-        QString report = reportInterface()->generateReportFullText(false) + QLatin1Char('\n') +
+        QString report = reportInterface()->generateReportFullText(ReportInterface::DrKonqiStamp::Exclude,
+                                                                   ReportInterface::Backtrace::Complete) + QLatin1Char('\n') +
                             i18nc("@info report to KDE bugtracker address","Report to %1",
                                   DrKonqi::crashedApplication()->bugReportAddress());
         m_contentsDialog = new ReportInformationDialog(report);
@@ -803,104 +769,3 @@ void BugzillaSendPage::openReportContents()
 }
 
 //END BugzillaSendPage
-
-/* Dialog for Unhandled Bugzilla Errors */
-/* The user can save the bugzilla html output to check the error and/or to report this as a DrKonqi bug */
-
-//BEGIN UnhandledErrorDialog
-
-UnhandledErrorDialog::UnhandledErrorDialog(QWidget * parent, const QString & error, const QString & extendedMessage)
-    : QDialog(parent)
-{
-    setWindowTitle(i18nc("@title:window", "Unhandled Bugzilla Error"));
-    setWindowModality(Qt::ApplicationModal);
-
-    QPushButton* saveButton = new QPushButton(this);
-    saveButton->setText(i18nc("@action:button save html to a file","Save to a file"));
-    saveButton->setIcon(QIcon::fromTheme(QStringLiteral("document-save")));
-    connect(saveButton, &QPushButton::clicked, this, &UnhandledErrorDialog::saveErrorMessage);
-
-    setAttribute(Qt::WA_DeleteOnClose);
-
-    QTextBrowser * htmlView = new QTextBrowser(this);
-
-    QLabel * iconLabel = new QLabel(this);
-    iconLabel->setFixedSize(32, 32);
-    iconLabel->setPixmap(QIcon::fromTheme(QStringLiteral("dialog-warning")).pixmap(32, 32));
-
-    QLabel * mainLabel = new QLabel(this);
-    mainLabel->setWordWrap(true);
-    mainLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
-
-    QHBoxLayout * titleLayout = new QHBoxLayout();
-    titleLayout->setContentsMargins(5,2,5,2);
-    titleLayout->setSpacing(5);
-    titleLayout->addWidget(iconLabel);
-    titleLayout->addWidget(mainLabel);
-
-    QDialogButtonBox* buttonBox = new QDialogButtonBox(this);
-    buttonBox->setStandardButtons(QDialogButtonBox::Close);
-    connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
-    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
-
-    QVBoxLayout * layout = new QVBoxLayout(this);
-    layout->addLayout(titleLayout);
-    layout->addWidget(htmlView);
-    layout->addWidget(buttonBox);
-
-    m_extendedHTMLError = extendedMessage;
-    mainLabel->setText(i18nc("@label", "There was an unhandled Bugzilla error: %1.<br />"
-                              "Below is the HTML that DrKonqi received. "
-                              "Try to perform the action again or save this error page "
-                              "to submit a bug against DrKonqi.").arg(error));
-    htmlView->setHtml(extendedMessage);
-
-    show();
-}
-
-void UnhandledErrorDialog::saveErrorMessage()
-{
-    QString defaultName = QLatin1String("drkonqi-unhandled-bugzilla-error.html");
-    QPointer<QFileDialog> dlg(new QFileDialog(this));
-    dlg->selectFile(defaultName);
-    dlg->setWindowTitle(i18nc("@title:window","Select Filename"));
-    dlg->setAcceptMode(QFileDialog::AcceptSave);
-    dlg->setFileMode(QFileDialog::AnyFile);
-    dlg->setConfirmOverwrite(true);
-
-    if ( dlg->exec() == QDialog::Accepted )
-    {
-        if (!dlg) {
-            //Dialog closed externally (ex. via DBus)
-            return;
-        }
-
-        QUrl fileUrl;
-        if(!dlg->selectedUrls().isEmpty())
-            fileUrl = dlg->selectedUrls().first();
-
-        if (fileUrl.isValid()) {
-            QTemporaryFile tf;
-            if (tf.open()) {
-                QTextStream ts(&tf);
-                ts << m_extendedHTMLError;
-                ts.flush();
-            } else {
-                KMessageBox::sorry(this, xi18nc("@info","Cannot open file <filename>%1</filename> "
-                                                "for writing.", tf.fileName()));
-                delete dlg;
-                return;
-            }
-
-            KIO::FileCopyJob* job = KIO::file_copy(QUrl::fromLocalFile(tf.fileName()), fileUrl);
-            KJobWidgets::setWindow(job, this);
-            if (!job->exec()) {
-                KMessageBox::sorry(this, job->errorString());
-            }
-        }
-    }
-    delete dlg;
-
-}
-
-//END UnhandledErrorDialog
